#!/bin/bash
function condor_restart_jobs(){
    if [[ -z $1 || $1 == "-h" ]]; then
        echo "Usage: condor_restart_jobs [-h] <restriction-list>

  <restriction-list> is one or more of:
    <cluster>          Edit jobs in a specific cluster
    <cluster>.<proc>   Edit a specific job
    <owner>            Edit jobs owned by <owner>
    -jobids <id-list>  Edit jobs in <id-list>
    -owner <owner>     Edit jobs owned by <owner>
    -constraint <expr> Edit jobs that match <expr>

  Reset job variables and release it (to restart it)

  The restriction-list should be: a list of job and/or cluster ids, a
  single owner name, or one or more of -owner, -jobids, -constraint arguments.
  If both owner and jobids are specified, only jobs that match both will be
  edited. If a -constraint argument is also provided, only jobs that also match
  the constraint will be edited.
  If only a -constraint argument is provided, jobs not owned by the current user
  will be ignored unless the current user is a queue superuser." >&2
        return 2
    fi

    # Follow logic in https://github.com/htcondor/htcondor/blob/master/src/condor_tools/qedit.cpp

    # Wrap the argument AFTER '-constraint' in quotes & concatenate all
    args=""; i=1
    while [[ $i -le "$#" ]]; do
        args+="${!i} "
        if [[ ${!i} == "-constraint" ]]; then
            i=$[$i+1]
            args+=\"${!i}\"
        fi
        i=$[$i+1]
    done

    condor_qedit $args \
        JobRunCount 0 \
        NumJobReconnects 0 \
        NumJobStarts 0 \
        NumJobMatches 0 \
        NumSystemHolds 0 \
        NumRestarts 0 \
        NumShadowStarts 0

    if [ $? -ne 0 ]; then
        return
    fi

    condor_release $args -totals -reason 'Restarted by condor_restart_jobs'
}

function condor_collector_load(){
    local collector="ekpcondorcentral.ekp.kit.edu"
    local lowport=20001
    local highport=20021
    printf "Main Collector:\t%.3f\n" $(condor_status -pool $collector -collector -af: 'RecentDaemonCoreDutyCycle')
    for i in $(seq $lowport $highport); do
        printf "Port %d:\t%.3f\n" $i $(condor_status -pool $collector:$i -collector -af: 'RecentDaemonCoreDutyCycle')
    done
}
